@@ -5,6 +5,7 @@ from urllib import parse
 import json 
 import os  
 import uuid
+import traceback
 
 
 def convertToPdf(file,options):
@@ -18,27 +19,30 @@ def convertToPdf(file,options):
             fileName ="./{}.xlsx".format(uuid.uuid4())
             with open(fileName,"wb") as out:
                 out.write(bytesArray)
-                file = fileName 
+                
+                file = os.path.abspath(fileName )
     
         fileDetails = file.split('.')
         fileDetails.pop() 
         fileDetails.append("pdf")
         fileNameForPdf = ".".join(fileDetails)
-        commandStrings =["java","-jar",os.path.dirname(__file__)+"/"+"app.jar",file ,file ,parse.quote(json.dumps(options))]  
+
+        filePathForPdf = os.path.join(os.path.abspath("."),fileNameForPdf)
+        commandStrings =["java","-jar",os.path.join(os.path.dirname(__file__),"app.jar"),file ,file ,parse.quote(json.dumps(options))]  
         command = " ".join(commandStrings) 
         res =subprocess.run(command) 
         
-        pdfCommandString = ["python", os.path.dirname(__file__)+"/unoconv", "-f","pdf",file ] 
+        pdfCommandString = ["python", os.path.join(os.path.dirname(__file__),"unoconv"),"-o",filePathForPdf , "-f","pdf",file ] 
 
         resPdf = subprocess.run(" ".join(pdfCommandString))
-        return_data = open(fileNameForPdf,"rb").read() 
+        return_data = open(filePathForPdf,"rb").read() 
         os.unlink(file)
-        os.unlink(fileNameForPdf)
+        os.unlink(filePathForPdf)
         return return_data
 
     except Exception as e: 
         print(e)
-    
+        traceback.print_stack()
 
 
 
